@@ -5,7 +5,7 @@ summary.reg <- function(object, ...)
    cat("Mean coefficients: ")
    c <- colMeans(x$coeff.,na.rm=TRUE)
    cat("\n")
-   print(round(c,digits=4))
+   print(round(c,digits=4),quote=FALSE)
    cat("\n")
    cat("Frequency when p-values for t-test are less than: ")
    cat("\n")
@@ -27,7 +27,7 @@ summary.reg <- function(object, ...)
    vv <- round(vv,digits=2)
    colnames(vv) <- colnames(x$p.val.)
    rownames(vv) <- c("0.01","0.05","0.10")
-   print(vv)
+   print(vv,quote=FALSE)
    cat("\n")
    e <- (mean((as.vector(x$y)-as.vector(x$y.hat))^2,na.rm=TRUE))^0.5
    e <- round(e,digits=4)
@@ -38,4 +38,5 @@ summary.reg <- function(object, ...)
    cat("MAE:  ",e)
    cat("\n")
    if (! is.null(x$window)) { cat("rolling window: ",x$window) } 
+   cat("\n")
   }
